@@ -1,4 +1,4 @@
-# $Id: Node.pm,v 1.20 2002/11/01 16:13:09 joern Exp $
+# $Id: Node.pm,v 1.21 2002/11/12 22:04:40 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -203,11 +203,16 @@ sub get_popen_code {
 sub reset {
 	my $self = shift;
 	
+	my $startup_state = $self->state;
+
 	$self->set_alive(0);
+	$self->set_state ($startup_state);
 	$self->set_answered_last_ping(0);
 	$self->set_state ('unknown')
-		if $self->state ne 'stopped' and
-		   $self->state ne 'aborted';
+		if $startup_state ne 'stopped' and
+		   $startup_state ne 'aborted';
+
+	$self->save;
 
 	1;
 }
@@ -241,7 +246,9 @@ sub start {
 
 	$self->log ("Node '".$self->name."' started");
 
+	$self->set_alive ( 0 );
 	$self->set_state ('unknown');
+	$self->set_answered_last_ping ( 1 );
 	$self->save;
 
 	Video::DVDRip::Cluster::Master->get_master->node_check;
