@@ -1,4 +1,4 @@
-# $Id: Project.pm,v 1.33 2002/11/06 08:18:44 joern Exp $
+# $Id: Project.pm,v 1.33.2.1 2002/11/23 13:45:29 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -127,7 +127,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or confess "can't write $filename";
-	print $fh q{# $Id: Project.pm,v 1.33 2002/11/06 08:18:44 joern Exp $},"\n";
+	print $fh q{# $Id: Project.pm,v 1.33.2.1 2002/11/23 13:45:29 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
@@ -246,6 +246,24 @@ sub rip_data_source {
 	return $source;
 }
 
+sub dvd_mount_dir {
+	my $self = shift; $self->trace_in;
+	
+	my $mode = $self->rip_mode;
+
+	my $dir;
+
+	if ( $mode eq 'rip' or $mode eq 'dvd' ) {
+		$dir = $self->config('dvd_mount_point');
+
+	} elsif ( $mode eq 'dvd_image' ) {
+		$dir = $self->dvd_image_dir;
+
+	}
+
+	return $dir;
+}
+
 sub convert_from_old_version {
 	my $self = shift;
 	my %par = @_;
@@ -371,7 +389,7 @@ sub copy_ifo_files {
 	$self->mount_dvd if not $mounted;
 
 	my @files = glob (
-		$self->config('dvd_mount_point').
+		$self->dvd_mount_dir.
 		"/{video_ts,VIDEO_TS}/{vts,VTS}*{ifo,IFO}"
 	);
 
@@ -391,8 +409,6 @@ sub copy_ifo_files {
 sub check_dvd_in_drive {
 	my $self = shift;
 	
-	my $rip_mode = $self->rip_mode;
-
 	my $dvd_device = $self->rip_data_source;
 
 	my $command = "tcprobe -i $dvd_device >/dev/null 2>&1";
